from EntropySGD.EntropySGD import EntropySgd
from EntropySGD.EntropyAdam import EntropyAdam
from EntropySGD.History import History